@@ -24,7 +24,6 @@ import enum
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import uuidutils
-import six
 
 from zaqar.common import decorators
 from zaqar.storage import errors
@@ -35,6 +34,7 @@ DEFAULT_QUEUES_PER_PAGE = 10
 DEFAULT_MESSAGES_PER_PAGE = 10
 DEFAULT_POOLS_PER_PAGE = 10
 DEFAULT_SUBSCRIPTIONS_PER_PAGE = 10
+DEFAULT_TOPICS_PER_PAGE = 10
 
 DEFAULT_MESSAGES_PER_CLAIM = 10
 
@@ -51,8 +51,7 @@ class Capabilities(enum.IntEnum):
     HIGH_THROUGHPUT = 5
 
 
-@six.add_metaclass(abc.ABCMeta)
-class DriverBase(object):
+class DriverBase(object, metaclass=abc.ABCMeta):
     """Base class for both data and control plane drivers
 
     :param conf: Configuration containing options for this driver.
@@ -77,8 +76,7 @@ class DriverBase(object):
                     pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class DataDriverBase(DriverBase):
+class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
     """Interface definition for storage drivers.
 
     Data plane storage drivers are responsible for implementing the
@@ -107,7 +105,8 @@ class DataDriverBase(DriverBase):
         """Check whether the storage is ready."""
         raise NotImplementedError
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def capabilities(self):
         """Returns storage's capabilities."""
         return self.BASE_CAPABILITIES
@@ -154,9 +153,10 @@ class DataDriverBase(DriverBase):
             try:
                 start = time.time()
                 result = callable_operation()
-            except Exception as e:
+            except Exception:
                 ref = uuidutils.generate_uuid()
-                LOG.exception(e, extra={'instance_uuid': ref})
+                LOG.exception('Error calling operation.',
+                              extra={'instance_uuid': ref})
                 succeeded = False
             status = status_template(succeeded, time.time() - start, ref)
             op_status[operation_type] = status
@@ -227,24 +227,31 @@ class DataDriverBase(DriverBase):
     def queue_controller(self):
         return self.control_driver.queue_controller
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def message_controller(self):
         """Returns the driver's message controller."""
         raise NotImplementedError
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def claim_controller(self):
         """Returns the driver's claim controller."""
         raise NotImplementedError
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def subscription_controller(self):
         """Returns the driver's subscription controller."""
         raise NotImplementedError
 
+    @decorators.lazy_property(write=False)
+    def topic_controller(self):
+        """Returns the driver's topic controller."""
+        return self.control_driver.topic_controller
 
-@six.add_metaclass(abc.ABCMeta)
-class ControlDriverBase(DriverBase):
+
+class ControlDriverBase(DriverBase, metaclass=abc.ABCMeta):
     """Interface definition for control plane storage drivers.
 
     Storage drivers that work at the control plane layer allow one to
@@ -261,26 +268,36 @@ class ControlDriverBase(DriverBase):
     :type cache: `dogpile.cache.region.CacheRegion`
     """
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def catalogue_controller(self):
         """Returns the driver's catalogue controller."""
         raise NotImplementedError
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def pools_controller(self):
         """Returns storage's pool management controller."""
         raise NotImplementedError
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def flavors_controller(self):
         """Returns storage's flavor management controller."""
         raise NotImplementedError
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def queue_controller(self):
         """Returns the driver's queue controller."""
         raise NotImplementedError
 
+    @property
+    @abc.abstractmethod
+    def topic_controller(self):
+        """Returns the driver's topic controller."""
+        raise NotImplementedError
+
     @abc.abstractmethod
     def close(self):
         """Close connections to the backend."""
@@ -298,8 +315,7 @@ class ControllerBase(object):
         self.driver = driver
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Queue(ControllerBase):
+class Queue(ControllerBase, metaclass=abc.ABCMeta):
     """This class is responsible for managing queues.
 
     Queue operations include CRUD, monitoring, etc.
@@ -407,9 +423,18 @@ class Queue(ControllerBase):
 
     _stats = abc.abstractmethod(lambda x: None)
 
+    def calculate_resource_count(self, project=None):
+        """Base method for calculate queues amount.
 
-@six.add_metaclass(abc.ABCMeta)
-class Message(ControllerBase):
+        :param project: Project id
+        :returns: The number of queues.
+        """
+        return self._calculate_resource_count(project)
+
+    _calculate_resource_count = abc.abstractmethod(lambda x: None)
+
+
+class Message(ControllerBase, metaclass=abc.ABCMeta):
     """This class is responsible for managing message CRUD."""
 
     @abc.abstractmethod
@@ -515,7 +540,7 @@ class Message(ControllerBase):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def bulk_delete(self, queue, message_ids, project=None):
+    def bulk_delete(self, queue, message_ids, project=None, claim_ids=None):
         """Base method for deleting multiple messages.
 
         :param queue: Name of the queue to post
@@ -523,6 +548,7 @@ class Message(ControllerBase):
         :param message_ids: A sequence of message IDs
             to be deleted.
         :param project: Project id
+        :param claim_ids: claim IDs passed in by the delete request
         """
         raise NotImplementedError
 
@@ -538,8 +564,7 @@ class Message(ControllerBase):
         raise NotImplementedError
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Claim(ControllerBase):
+class Claim(ControllerBase, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get(self, queue, claim_id, project=None):
@@ -597,8 +622,7 @@ class Claim(ControllerBase):
         raise NotImplementedError
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Subscription(ControllerBase):
+class Subscription(ControllerBase, metaclass=abc.ABCMeta):
     """This class is responsible for managing subscriptions of notification.
 
     """
@@ -609,11 +633,11 @@ class Subscription(ControllerBase):
         """Base method for listing subscriptions.
 
         :param queue: Name of the queue to get the subscriptions from.
-        :type queue: six.text_type
+        :type queue: str
         :param project: Project this subscription belongs to.
-        :type project: six.text_type
+        :type project: str
         :param marker: used to determine which subscription to start with
-        :type marker: six.text_type
+        :type marker: str
         :param limit: (Default 10) Max number of results to return
         :type limit: int
         :returns: An iterator giving a sequence of subscriptions
@@ -627,11 +651,11 @@ class Subscription(ControllerBase):
         """Returns a single subscription entry.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: six.text_type
+        :type queue: str
         :param subscription_id: ID of this subscription
-        :type subscription_id: six.text_type
+        :type subscription_id: str
         :param project: Project this subscription belongs to.
-        :type project: six.text_type
+        :type project: str
         :returns: Dictionary containing subscription data
         :rtype: {}
         :raises SubscriptionDoesNotExist: if not found
@@ -643,15 +667,15 @@ class Subscription(ControllerBase):
         """Create a new subscription.
 
         :param queue:The source queue for notifications
-        :type queue: six.text_type
+        :type queue: str
         :param subscriber: The subscriber URI
-        :type subscriber: six.text_type
+        :type subscriber: str
         :param ttl: time to live for this subscription
         :type ttl: int
         :param options: Options used to configure this subscription
         :type options: dict
         :param project: Project id
-        :type project: six.text_type
+        :type project: str
         :returns: True if a subscription was created and False
         if it is failed.
         :rtype: boolean
@@ -663,7 +687,7 @@ class Subscription(ControllerBase):
         """Updates the weight, uris, and/or options of this subscription
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: six.text_type
+        :type queue: str
         :param name: ID of the subscription
         :type name: text
         :param kwargs: one of: `source`, `subscriber`, `ttl`, `options`
@@ -680,11 +704,11 @@ class Subscription(ControllerBase):
         """Base method for testing subscription existence.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: six.text_type
+        :type queue: str
         :param subscription_id: ID of subscription
-        :type subscription_id: six.text_type
+        :type subscription_id: str
         :param project: Project id
-        :type project: six.text_type
+        :type project: str
         :returns: True if a subscription exists and False
             if it does not.
         """
@@ -695,11 +719,11 @@ class Subscription(ControllerBase):
         """Base method for deleting a subscription.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: six.text_type
+        :type queue: str
         :param subscription_id: ID of the subscription to be deleted.
-        :type subscription_id: six.text_type
+        :type subscription_id: str
         :param project: Project id
-        :type project: six.text_type
+        :type project: str
         """
         raise NotImplementedError
 
@@ -708,11 +732,11 @@ class Subscription(ControllerBase):
         """Base method for get a subscription with the subscriber.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: six.text_type
+        :type queue: str
         :param subscriber: link of the subscription to be notified.
-        :type subscriber: six.text_type
+        :type subscriber: str
         :param project: Project id
-        :type project: six.text_type
+        :type project: str
         :returns: Dictionary containing subscription data
         :rtype: dict
         """
@@ -723,11 +747,11 @@ class Subscription(ControllerBase):
         """Base method for confirming a subscription.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: six.text_type
+        :type queue: str
         :param subscription_id: ID of the subscription to be deleted.
-        :type subscription_id: six.text_type
+        :type subscription_id: str
         :param project: Project id
-        :type project: six.text_type
+        :type project: str
         :param confirmed: Confirm a subscription or cancel the confirmation of
             a subscription.
         :type confirmed: boolean
@@ -735,8 +759,7 @@ class Subscription(ControllerBase):
         raise NotImplementedError
 
 
-@six.add_metaclass(abc.ABCMeta)
-class PoolsBase(ControllerBase):
+class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
     """A controller for managing pools."""
 
     def _check_capabilities(self, uri, flavor=None, name=None):
@@ -758,9 +781,9 @@ class PoolsBase(ControllerBase):
         """Gets the set of capabilities for this flavor/name
 
         :param flavor: The pool flavor to get capabilities for
-        :type flavor: six.text_type
+        :type flavor: str
         :param name: The pool name to get capabilities for
-        :type name: six.text_type
+        :type name: str
         """
         pllt = []
         if name:
@@ -784,7 +807,7 @@ class PoolsBase(ControllerBase):
         """Lists all registered pools.
 
         :param marker: used to determine which pool to start with
-        :type marker: six.text_type
+        :type marker: str
         :param limit: (Default 10) Max number of results to return
         :type limit: int
         :param detailed: whether to include options
@@ -797,30 +820,28 @@ class PoolsBase(ControllerBase):
 
     _list = abc.abstractmethod(lambda x: None)
 
-    def create(self, name, weight, uri, group=None, flavor=None, options=None):
+    def create(self, name, weight, uri, flavor=None, options=None):
         """Registers a pool entry.
 
         :param name: The name of this pool
-        :type name: six.text_type
+        :type name: str
         :param weight: the likelihood that this pool will be used
         :type weight: int
         :param uri: A URI that can be used by a storage client
             (e.g., pymongo) to access this pool.
-        :type uri: six.text_type
+        :type uri: str
         :param flavor: The flavor of this pool
-        :type flavor: six.text_type
+        :type flavor: str
         :param options: Options used to configure this pool
         :type options: dict
         """
         flavor_obj = {}
         if flavor is not None:
             flavor_obj["name"] = flavor
-        if group is not None:
-            flavor_obj["pool_group"] = group
         if not self._check_capabilities(uri, flavor=flavor_obj):
             raise errors.PoolCapabilitiesMismatch()
 
-        return self._create(name, weight, uri, group, flavor, options)
+        return self._create(name, weight, uri, flavor, options)
 
     _create = abc.abstractmethod(lambda x: None)
 
@@ -829,7 +850,7 @@ class PoolsBase(ControllerBase):
 
         :param flavor: The flavor to filter on. `None` returns
             pools that are not assigned to any pool flavor.
-        :type flavor: six.text_type
+        :type flavor: str
         :param detailed: Should the options data be included?
         :type detailed: bool
         :returns: weight, uri, and options for this pool
@@ -844,7 +865,7 @@ class PoolsBase(ControllerBase):
         """Returns a single pool entry.
 
         :param name: The name of this pool
-        :type name: six.text_type
+        :type name: str
         :param detailed: Should the options data be included?
         :type detailed: bool
         :returns: weight, uri, and options for this pool
@@ -859,7 +880,7 @@ class PoolsBase(ControllerBase):
         """Returns a single pool entry.
 
         :param name: The name of this pool
-        :type name: six.text_type
+        :type name: str
         :returns: True if the pool exists
         :rtype: bool
         """
@@ -871,7 +892,7 @@ class PoolsBase(ControllerBase):
         """Removes a pool entry.
 
         :param name: The name of this pool
-        :type name: six.text_type
+        :type name: str
         :rtype: None
         """
         return self._delete(name)
@@ -902,8 +923,7 @@ class PoolsBase(ControllerBase):
     _drop_all = abc.abstractmethod(lambda x: None)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class CatalogueBase(ControllerBase):
+class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
     """A controller for managing the catalogue.
 
     The catalogue is responsible for maintaining a mapping
@@ -916,7 +936,7 @@ class CatalogueBase(ControllerBase):
 
         :param project: The project to use when filtering through queue
                         entries.
-        :type project: six.text_type
+        :type project: str
         :returns: [{'project': ..., 'queue': ..., 'pool': ...},]
         :rtype: [dict]
         """
@@ -928,9 +948,9 @@ class CatalogueBase(ControllerBase):
         """Returns the pool identifier for the given queue.
 
         :param project: Namespace to search for the given queue
-        :type project: six.text_type
+        :type project: str
         :param queue: The name of the queue to search for
-        :type queue: six.text_type
+        :type queue: str
         :returns: {'pool': ...}
         :rtype: dict
         :raises QueueNotMapped: if queue is not mapped
@@ -943,9 +963,9 @@ class CatalogueBase(ControllerBase):
         """Determines whether the given queue exists under project.
 
         :param project: Namespace to check.
-        :type project: six.text_type
+        :type project: str
         :param queue: str - Particular queue to check for
-        :type queue: six.text_type
+        :type queue: str
         :return: True if the queue exists under this project
         :rtype: bool
         """
@@ -955,11 +975,11 @@ class CatalogueBase(ControllerBase):
         """Creates a new catalogue entry, or updates it if it already exists.
 
         :param project: str - Namespace to insert the given queue into
-        :type project: six.text_type
+        :type project: str
         :param queue: str - The name of the queue to insert
-        :type queue: six.text_type
+        :type queue: str
         :param pool: pool identifier to associate this queue with
-        :type pool: six.text_type
+        :type pool: str
         """
 
         raise NotImplementedError
@@ -969,9 +989,9 @@ class CatalogueBase(ControllerBase):
         """Removes this entry from the catalogue.
 
         :param project: The namespace to search for this queue
-        :type project: six.text_type
+        :type project: str
         :param queue: The queue name to remove
-        :type queue: six.text_type
+        :type queue: str
         """
 
         raise NotImplementedError
@@ -981,11 +1001,11 @@ class CatalogueBase(ControllerBase):
         """Updates the pool identifier for this queue.
 
         :param project: Namespace to search
-        :type project: six.text_type
+        :type project: str
         :param queue: The name of the queue
-        :type queue: six.text_type
+        :type queue: str
         :param pools: The name of the pool where this project/queue lives.
-        :type pools: six.text_type
+        :type pools: str
         :raises QueueNotMapped: if queue is not mapped
         """
 
@@ -998,8 +1018,7 @@ class CatalogueBase(ControllerBase):
         raise NotImplementedError
 
 
-@six.add_metaclass(abc.ABCMeta)
-class FlavorsBase(ControllerBase):
+class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
     """A controller for managing flavors."""
 
     @abc.abstractmethod
@@ -1007,9 +1026,9 @@ class FlavorsBase(ControllerBase):
         """Lists all registered flavors.
 
         :param project: Project this flavor belongs to.
-        :type project: six.text_type
+        :type project: str
         :param marker: used to determine which flavor to start with
-        :type marker: six.text_type
+        :type marker: str
         :param limit: (Default 10) Max number of results to return
         :type limit: int
         :returns: A list of flavors - name, project, flavor
@@ -1019,15 +1038,15 @@ class FlavorsBase(ControllerBase):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def create(self, name, pool_group=None, project=None, capabilities=None):
+    def create(self, name, project=None, capabilities=None):
         """Registers a flavor entry.
 
         :param name: The name of this flavor
-        :type name: six.text_type
+        :type name: str
         :param project: Project this flavor belongs to.
-        :type project: six.text_type
+        :type project: str
         :param pool: The name of the pool to use for this flavor.
-        :type pool: six.text_type
+        :type pool: str
         :param capabilities: Flavor capabilities
         :type capabilities: dict
         """
@@ -1039,9 +1058,9 @@ class FlavorsBase(ControllerBase):
         """Returns a single flavor entry.
 
         :param name: The name of this flavor
-        :type name: six.text_type
+        :type name: str
         :param project: Project this flavor belongs to.
-        :type project: six.text_type
+        :type project: str
         :rtype: {}
         :raises FlavorDoesNotExist: if not found
         """
@@ -1053,9 +1072,9 @@ class FlavorsBase(ControllerBase):
         """Verifies whether the flavor exists.
 
         :param name: The name of this flavor
-        :type name: six.text_type
+        :type name: str
         :param project: Project this flavor belongs to.
-        :type project: six.text_type
+        :type project: str
         :returns: True if the flavor exists
         :rtype: bool
         """
@@ -1067,9 +1086,9 @@ class FlavorsBase(ControllerBase):
         """Removes a flavor entry.
 
         :param name: The name of this flavor
-        :type name: six.text_type
+        :type name: str
         :param project: Project this flavor belongs to.
-        :type project: six.text_type
+        :type project: str
         :rtype: None
         """
 
@@ -1082,7 +1101,7 @@ class FlavorsBase(ControllerBase):
         :param name: Name of the flavor
         :type name: text
         :param project: Project this flavor belongs to.
-        :type project: six.text_type
+        :type project: str
         :param kwargs: one of: `uri`, `weight`, `options`
         :type kwargs: dict
         :raises FlavorDoesNotExist: if not found
@@ -1095,3 +1114,112 @@ class FlavorsBase(ControllerBase):
         """Deletes all flavors from storage."""
 
         raise NotImplementedError
+
+
+class Topic(ControllerBase, metaclass=abc.ABCMeta):
+    """This class is responsible for managing topics.
+
+    Topic operations include CRUD, etc.
+
+    Storage driver implementations of this class should
+    be capable of handling high workloads and huge
+    numbers of topics.
+    """
+
+    def list(self, project=None, kfilter={}, marker=None,
+             limit=DEFAULT_TOPICS_PER_PAGE, detailed=False, name=None):
+        """Base method for listing topics.
+
+        :param project: Project id
+        :param kfilter: The key-value of metadata which user want to filter
+        :param marker: The last topic name
+        :param limit: (Default 10) Max number of topics to return
+        :param detailed: Whether metadata is included
+        :param name: The topic name which user want to filter
+
+        :returns: An iterator giving a sequence of topics
+            and the marker of the next page.
+        """
+        return self._list(project, kfilter, marker, limit, detailed, name)
+
+    _list = abc.abstractmethod(lambda x: None)
+
+    def get(self, name, project=None):
+        """Base method for topic metadata retrieval.
+
+        :param name: The topic name
+        :param project: Project id
+
+        :returns: Dictionary containing topic metadata
+        :raises DoesNotExist: if topic metadata does not exist
+        """
+        return self._get(name, project)
+
+    _get = abc.abstractmethod(lambda x: None)
+
+    def get_metadata(self, name, project=None):
+        """Base method for topic metadata retrieval.
+
+        :param name: The topic name
+        :param project: Project id
+
+        :returns: Dictionary containing topic metadata
+        :raises DoesNotExist: if topic metadata does not exist
+        """
+        raise NotImplementedError
+
+    def set_metadata(self, name, metadata, project=None):
+        """Base method for updating a topic metadata.
+
+        :param name: The topic name
+        :param metadata: Topic metadata as a dict
+        :param project: Project id
+        :raises DoesNotExist: if topic metadata can not be updated
+        """
+        raise NotImplementedError
+
+    def create(self, name, metadata=None, project=None):
+        """Base method for topic creation.
+
+        :param name: The topic name
+        :param project: Project id
+        :returns: True if a topic was created and False
+            if it was updated.
+        """
+        return self._create(name, metadata, project)
+
+    _create = abc.abstractmethod(lambda x: None)
+
+    def exists(self, name, project=None):
+        """Base method for testing topic existence.
+
+        :param name: The topic name
+        :param project: Project id
+        :returns: True if a topic exists and False
+            if it does not.
+        """
+        return self._exists(name, project)
+
+    _exists = abc.abstractmethod(lambda x: None)
+
+    def delete(self, name, project=None):
+        """Base method for deleting a topic.
+
+        :param name: The topic name
+        :param project: Project id
+        """
+        return self._delete(name, project)
+
+    _delete = abc.abstractmethod(lambda x: None)
+
+    def stats(self, name, project=None):
+        """Base method for topic stats.
+
+        :param name: The topic name
+        :param project: Project id
+        :returns: Dictionary with the
+            queue stats
+        """
+        return self._stats(name, project)
+
+    _stats = abc.abstractmethod(lambda x: None)
