@@ -38,15 +38,18 @@ LOG = logging.getLogger(__name__)
 def _messages_iter(msg_iter):
     """Used to iterate through messages."""
 
-    msg = next(msg_iter)
-    yield msg.pop('claim')
-    yield msg
-
-    # Smoke it!
-    for msg in msg_iter:
-        del msg['claim']
+    try:
+        msg = next(msg_iter)
+        yield msg.pop('claim')
         yield msg
 
+        # Smoke it!
+        for msg in msg_iter:
+            del msg['claim']
+            yield msg
+    except StopIteration:
+        return
+
 
 class ClaimController(storage.Claim):
     """Implements claim resource operations using MongoDB.
@@ -130,7 +133,9 @@ class ClaimController(storage.Claim):
         """
         msg_ctrl = self.driver.message_controller
         queue_ctrl = self.driver.queue_controller
-
+        # Get the maxClaimCount, deadLetterQueue and DelayTTL
+        # from current queue's meta
+        queue_meta = queue_ctrl.get(queue, project=project)
         ttl = metadata['ttl']
         grace = metadata['grace']
         oid = objectid.ObjectId()
@@ -150,11 +155,17 @@ class ClaimController(storage.Claim):
             'c': 0   # NOTE(flwang): A placeholder which will be updated later
         }
 
+        # NOTE(cdyangzhenyu): If the ``_default_message_delay`` is 0 means
+        # queue is not delayed queue, So we don't filter for delay messages.
+        include_delayed = False if queue_meta.get('_default_message_delay',
+                                                  0) else True
+
         # Get a list of active, not claimed nor expired
         # messages that could be claimed.
         msgs = msg_ctrl._active(queue, projection={'_id': 1, 'c': 1},
                                 project=project,
-                                limit=limit)
+                                limit=limit,
+                                include_delayed=include_delayed)
 
         messages = iter([])
         be_claimed = [(msg['_id'], msg['c'].get('c', 0)) for msg in msgs]
@@ -163,11 +174,6 @@ class ClaimController(storage.Claim):
         if len(ids) == 0:
             return None, messages
 
-        # Get the maxClaimCount and deadLetterQueue from current queue's meta
-        queue_meta = queue_ctrl.get(queue, project=project)
-
-        now = timeutils.utcnow_ts()
-
         # NOTE(kgriffs): Set the claim field for
         # the active message batch, while also
         # filtering out any messages that happened
@@ -241,7 +247,7 @@ class ClaimController(storage.Claim):
                                                          {'$set': new_msg},
                                                          **kwargs)
                     dlq_collection = msg_ctrl._collection(dlq_name, project)
-                    if not dlq_collection:
+                    if dlq_collection is None:
                         LOG.warning(u"Failed to find the message collection "
                                     u"for queue %(dlq_name)s", {"dlq_name":
                                                                 dlq_name})
