@@ -14,12 +14,12 @@
 
 import copy
 import hashlib
-import json
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_serialization import jsonutils
 from osprofiler import profiler
-from stevedore import driver
+import stevedore
 from urllib import parse as urllib_parse
 
 from zaqar.common import errors
@@ -86,11 +86,17 @@ def load_storage_impl(uri, control_mode=False, default_store=None):
 
     mode = 'control' if control_mode else 'data'
     driver_type = 'zaqar.{0}.storage'.format(mode)
-    storage_type = urllib_parse.urlparse(uri).scheme or default_store
+    # Note(wanghao): In python3.9, urlparse will return 'localhost' as scheme
+    # instead of '' in python3.8 when uri string is 'localhost:xxxxx'. So there
+    # need to handle this change.
+    storage_type = urllib_parse.urlparse(uri).scheme
+    if storage_type == '' or storage_type == 'localhost':
+        storage_type = default_store
 
     try:
-        mgr = driver.DriverManager(driver_type, storage_type,
-                                   invoke_on_load=False)
+        mgr = stevedore.DriverManager(namespace=driver_type,
+                                      name=storage_type,
+                                      invoke_on_load=False)
 
         return mgr.driver
 
@@ -133,10 +139,10 @@ def load_storage_driver(conf, cache, storage_type=None,
         _invoke_args = (conf, cache, control_driver)
 
     try:
-        mgr = driver.DriverManager(driver_type,
-                                   storage_type,
-                                   invoke_on_load=True,
-                                   invoke_args=_invoke_args)
+        mgr = stevedore.DriverManager(namespace=driver_type,
+                                      name=storage_type,
+                                      invoke_on_load=True,
+                                      invoke_args=_invoke_args)
 
         if conf.profiler.enabled:
             if ((mode == "control" and conf.profiler.trace_management_store) or
@@ -229,7 +235,7 @@ def get_checksum(body, algorithm='MD5'):
     if body is None:
         return ''
     else:
-        checksum_body = json.dumps(body).encode('utf-8')
+        checksum_body = jsonutils.dump_as_bytes(body)
     # TODO(yangzhenyu): We may support other algorithms in future
     # versions, including SHA1, SHA256, SHA512, and so on.
     if algorithm == 'MD5':
