@@ -16,12 +16,12 @@
 import falcon
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
-import six.moves.urllib.parse as urlparse
+from urllib import parse as urlparse
 
 from zaqar.tests.unit.transport.wsgi import base
 
 
-class TestHomeDocument(base.V1_1Base):
+class TestHomeDocument(base.V2Base):
 
     config_file = 'wsgi_mongodb.conf'
 
