@@ -28,8 +28,7 @@ following fields are required:
     }
 
 Furthermore, depending on the underlying storage type of pool being
-registered, there is an optional field:
-::
+registered, there is an optional field::
 
     {
         "options": {...}
@@ -42,7 +41,6 @@ from oslo_log import log
 
 from zaqar.common.api.schemas import pools as schema
 from zaqar.common import utils as common_utils
-from zaqar.i18n import _
 from zaqar.storage import errors
 from zaqar.storage import utils as storage_utils
 from zaqar.transport import utils as transport_utils
@@ -87,9 +85,10 @@ class Listing(object):
         request.get_param_as_bool('detailed', store=store)
 
         cursor = self._ctrl.list(**store)
+
         pools = list(next(cursor))
 
-        results = {'links': []}
+        results = {}
 
         if pools:
             store['marker'] = next(cursor)
@@ -97,13 +96,12 @@ class Listing(object):
             for entry in pools:
                 entry['href'] = request.path + '/' + entry['name']
 
-            results['links'] = [
-                {
-                    'rel': 'next',
-                    'href': request.path + falcon.to_query_str(store)
-                }
-            ]
-
+        results['links'] = [
+            {
+                'rel': 'next',
+                'href': request.path + falcon.to_query_str(store)
+            }
+        ]
         results['pools'] = pools
 
         response.content_location = request.relative_uri
@@ -123,7 +121,6 @@ class Resource(object):
         self._validators = {
             'weight': validator_type(schema.patch_weight),
             'uri': validator_type(schema.patch_uri),
-            'group': validator_type(schema.patch_uri),
             'options': validator_type(schema.patch_options),
             'create': validator_type(schema.create)
         }
@@ -135,9 +132,8 @@ class Resource(object):
 
             {"weight": 100, "uri": "", options: {...}}
 
-        :returns: HTTP | [200, 404]
+            :returns: HTTP | [200, 404]
         """
-
         LOG.debug(u'GET pool - name: %s', pool)
         data = None
         detailed = request.get_param_as_bool('detailed') or False
@@ -152,6 +148,7 @@ class Resource(object):
         data['href'] = request.path
 
         response.body = transport_utils.to_json(data)
+        response.content_location = request.relative_uri
 
     def on_put(self, request, response, project_id, pool):
         """Registers a new pool. Expects the following input:
@@ -180,10 +177,6 @@ class Resource(object):
                               options=data.get('options', {}))
             response.status = falcon.HTTP_201
             response.location = request.path
-        except errors.PoolCapabilitiesMismatch as e:
-            title = _(u'Unable to create pool')
-            LOG.exception(title)
-            raise falcon.HTTPBadRequest(title, str(e))
         except errors.PoolAlreadyExists as e:
             LOG.exception('Pool "%s" already exists', pool)
             raise wsgi_errors.HTTPConflict(str(e))
@@ -191,28 +184,18 @@ class Resource(object):
     def on_delete(self, request, response, project_id, pool):
         """Deregisters a pool.
 
-        :returns: HTTP | [204, 403]
+        :returns: HTTP | 204
         """
 
         LOG.debug(u'DELETE pool - name: %s', pool)
-
-        try:
-            self._ctrl.delete(pool)
-        except errors.PoolInUseByFlavor as ex:
-            title = _(u'Unable to delete')
-            description = _(u'This pool is used by flavors {flavor}; '
-                            u'It cannot be deleted.')
-            description = description.format(flavor=ex.flavor)
-            LOG.exception(description)
-            raise falcon.HTTPForbidden(title, description)
-
+        self._ctrl.delete(pool)
         response.status = falcon.HTTP_204
 
     def on_patch(self, request, response, project_id, pool):
         """Allows one to update a pool's weight, uri, and/or options.
 
         This method expects the user to submit a JSON object
-        containing at least one of: 'uri', 'weight', 'group', 'options'. If
+        containing at least one of: 'uri', 'weight', 'options'. If
         none are found, the request is flagged as bad. There is also
         strict format checking through the use of
         jsonschema. Appropriate errors are returned in each case for
@@ -228,7 +211,7 @@ class Resource(object):
         if not any([(field in data) for field in EXPECT]):
             LOG.debug(u'PATCH pool, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
-                'One of `uri`, `weight`,or `options` needs '
+                'One of `uri`, `weight`, or `options` needs '
                 'to be specified'
             )
 
